==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/authentication/KafkaClientAuthenticationScramSha512Fluent.java <==
package io.strimzi.api.kafka.model.authentication;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.PasswordSecretSource;
import java.lang.String;
import io.strimzi.api.kafka.model.PasswordSecretSourceFluent;
import java.lang.Boolean;
import io.strimzi.api.kafka.model.PasswordSecretSourceBuilder;

public interface KafkaClientAuthenticationScramSha512Fluent<A extends KafkaClientAuthenticationScramSha512Fluent<A>> extends Fluent<A>{


    public String getUsername();
    public A withUsername(String username);
    public Boolean hasUsername();
    public A withNewUsername(String arg1);
    public A withNewUsername(StringBuilder arg1);
    public A withNewUsername(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildPasswordSecret instead.
 * @return The buildable object.
 */
@Deprecated public PasswordSecretSource getPasswordSecret();
    public PasswordSecretSource buildPasswordSecret();
    public A withPasswordSecret(PasswordSecretSource passwordSecret);
    public Boolean hasPasswordSecret();
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> withNewPasswordSecret();
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> withNewPasswordSecretLike(PasswordSecretSource item);
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> editPasswordSecret();
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> editOrNewPasswordSecret();
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> editOrNewPasswordSecretLike(PasswordSecretSource item);

    public interface PasswordSecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PasswordSecretSourceFluent<KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<N>>{

        
    public N and();    public N endPasswordSecret();
}


}

==> api-0.23.0-sources.jar: io/strimzi/api/kafka/model/authentication/KafkaClientAuthenticationScramSha512Fluent.java <==
package io.strimzi.api.kafka.model.authentication;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.PasswordSecretSource;
import java.lang.String;
import io.strimzi.api.kafka.model.PasswordSecretSourceFluent;
import java.lang.Boolean;
import io.strimzi.api.kafka.model.PasswordSecretSourceBuilder;

public interface KafkaClientAuthenticationScramSha512Fluent<A extends KafkaClientAuthenticationScramSha512Fluent<A>> extends Fluent<A> {


    public String getUsername();
    public A withUsername(String username);
    public Boolean hasUsername();
    public A withNewUsername(StringBuilder arg1);
    public A withNewUsername(int[] arg1,int arg2,int arg3);
    public A withNewUsername(char[] arg1);
    public A withNewUsername(StringBuffer arg1);
    public A withNewUsername(byte[] arg1,int arg2);
    public A withNewUsername(byte[] arg1);
    public A withNewUsername(char[] arg1,int arg2,int arg3);
    public A withNewUsername(byte[] arg1,int arg2,int arg3);
    public A withNewUsername(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUsername(String arg1);
    
/**
 * This method has been deprecated, please use method buildPasswordSecret instead.
 * @return The buildable object.
 */
@Deprecated public PasswordSecretSource getPasswordSecret();
    public PasswordSecretSource buildPasswordSecret();
    public A withPasswordSecret(PasswordSecretSource passwordSecret);
    public Boolean hasPasswordSecret();
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> withNewPasswordSecret();
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> withNewPasswordSecretLike(PasswordSecretSource item);
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> editPasswordSecret();
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> editOrNewPasswordSecret();
    public KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<A> editOrNewPasswordSecretLike(PasswordSecretSource item);
    public interface PasswordSecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PasswordSecretSourceFluent<KafkaClientAuthenticationScramSha512Fluent.PasswordSecretNested<N>> {

            public N and();
            public N endPasswordSecret();    }


}
